# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Dist-CheckConflicts
Version:	0.11
Release:	27.%{__distinit}%{__distvers}
Summary:	Declare version conflicts for your dist
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Dist-CheckConflicts
Source0:	https://cpan.metacpan.org/modules/by-module/Dist/Dist-CheckConflicts-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.30
# Module
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Module::Runtime) >= 0.009
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(blib)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More) >= 0.88
# Extra Tests
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
One shortcoming of the CPAN clients that currently exist is that they have no
way of specifying conflicting downstream dependencies of modules. This module
attempts to work around this issue by allowing you to specify conflicting
versions of modules separately, and deal with them after the module is done
installing.

For instance, say you have a module Foo, and some other module Bar uses Foo. If
Foo were to change its API in a non-backwards-compatible way, this would cause
Bar to break until it is updated to use the new API. Foo can't just depend on
the fixed version of Bar, because this will cause a circular dependency
(because Bar is already depending on Foo), and this doesn't express intent
properly anyway - Foo doesn't use Bar at all. The ideal solution would be for
there to be a way to specify conflicting versions of modules in a way that would
let CPAN clients update conflicting modules automatically after an existing
module is upgraded, but until that happens, this module will allow users to do
this manually.

%prep
%setup -q -n Dist-CheckConflicts-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Dist/
%{_mandir}/man3/Dist::CheckConflicts.3*

%changelog
* Wed Apr  5 2023 Paul Howarth <paul@city-fan.org> - 0.11-27
- Use SPDX-format license tag
- Use %%license unconditionally

* Tue Mar 10 2020 Paul Howarth <paul@city-fan.org> - 0.11-18
- BR: perl(blib) for t/00-compile.t

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.11-15
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop support for building with Test::More < 0.88
  - Drop legacy BuildRoot: and Group: tags

* Fri Aug 19 2016 Paul Howarth <paul@city-fan.org> - 0.11-7
- BR: perl-generators where available
- Simplify find command using -delete

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 0.11-3
- Use %%license where possible

* Thu Apr  3 2014 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11
  - Drop the dep on List::MoreUtils
    (https://github.com/doy/dist-checkconflicts/pull/8)
- Drop support for old distributions prior to FC-5:
  - Drop %%defattr, redundant since rpm 4.4
  - Drop patch supporting building with ExtUtils::MakeMaker < 6.30
- Update patch for building with Test::More < 0.88

* Wed Dec 18 2013 Paul Howarth <paul@city-fan.org> - 0.10-1
- Update to 0.10
  - We need Module::Runtime 0.009 for module_notional_filename (#6)
- Update patches as needed

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09
  - Support Perl 5.6.x
- Update patches as needed

* Wed Jul 10 2013 Paul Howarth <paul@city-fan.org> - 0.08-1
- Update to 0.08
  - Remove the dependency on Test::Warnings
- Reinstate support for old distributions back to FC-3

* Tue Jul  9 2013 Paul Howarth <paul@city-fan.org> - 0.07-1
- Update to 0.07
  - Instead of silently ignoring conflicts that do not compile, issue a
    conflict warning (CPAN RT#75486)
- Drop support for old distributions as the test suite now requires
  Test::Warnings, which is unavailable prior to F-14
- BR: perl(Module::Runtime) and perl(Test::Warnings)
- Classify buildreqs by usage
- Explicitly run the extra tests

* Sat Jun 22 2013 Paul Howarth <paul@city-fan.org> - 0.06-1
- Update to 0.06
  - Add optional runtime conflict warnings
  - Require 5.8.1, clean up a few things and add a few more tests
  - Use Exporter instead of Sub::Exporter
- Update patches

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 0.02-6
- BR: perl(Carp), perl(File::Temp) and perl(lib)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Drop patch for using Test::Exception rather than Test::Fatal with 5.8.0
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Jun 24 2011 Paul Howarth <paul@city-fan.org> - 0.02-4
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jan  4 2011 Paul Howarth <paul@city-fan.org> - 0.02-1
- Initial RPM version
